@@ -253,7 +253,11 @@ gnome_app_destroy (GtkObject *object)
 	app = GNOME_APP (object);
 
 	g_free (app->name);
+	app->name = NULL;
 	g_free (app->prefix);
+	app->prefix = NULL;
+	gtk_accel_group_unref (app->accel_group);
+	app->accel_group = NULL;
 
 	if (GTK_OBJECT_CLASS (parent_class)->destroy)
 		(* GTK_OBJECT_CLASS (parent_class)->destroy) (object);
