@@ -89,6 +89,8 @@ popup_marshal_func (GtkObject *object, gpointer data, guint n_args, GtkArg *args
  * Creates a popup menu out of the specified uiinfo array.  Use
  * gnome_popup_menu_do_popup() to pop the menu up, or attach it to a
  * window with gnome_popup_menu_attach().
+ *
+ * Returns a menu widget
  */
 GtkWidget *
 gnome_popup_menu_new_with_accelgroup (GnomeUIInfo *uiinfo,
@@ -138,6 +140,9 @@ gnome_popup_menu_new_with_accelgroup (GnomeUIInfo *uiinfo,
  * accelgroup for you and attaches it to the menu object.  Use
  * gnome_popup_menu_get_accel_group() to get the accelgroup that is
  * created.
+ *
+ * Returns a menu widget
+ *
  */
 GtkWidget *
 gnome_popup_menu_new (GnomeUIInfo *uiinfo)
@@ -221,10 +226,10 @@ popup_attach_widget_destroyed (GtkWidget *widget, gpointer data)
 }
 
 /**
- * gnome_popup_menu_attach
- * @popup
- * @widget
- * @user_data
+ * gnome_popup_menu_attach:
+ * @popup:
+ * @widget:
+ * @user_data:
  *
  * Attaches the specified popup menu to the specified widget.  The
  * menu can then be activated by pressing mouse button 3 over the
@@ -282,12 +287,12 @@ gnome_popup_menu_attach (GtkWidget *popup, GtkWidget *widget,
 }
 
 /**
- * gnome_popup_menu_do_popup
- * @popup
- * @pos_func
- * @pos_data
- * @event
- * @user_data
+ * gnome_popup_menu_do_popup:
+ * @popup:
+ * @pos_func:
+ * @pos_data:
+ * @event:
+ * @user_data:
  *
  *
  * You can use this function to pop up a menu.  When a menu item *
@@ -312,7 +317,6 @@ gnome_popup_menu_do_popup (GtkWidget *popup, GtkMenuPositionFunc pos_func, gpoin
 
 	g_return_if_fail (popup != NULL);
 	g_return_if_fail (GTK_IS_WIDGET (popup));
-	g_return_if_fail (event != NULL);
 
 	/* Store the user data in the menu for when a callback is activated -- if it is a
 	 * Gnome-generated menu, then the user data will be passed on to callbacks by our custom
@@ -357,12 +361,12 @@ get_active_index (GtkMenu *menu)
 }
 
 /**
- * gnome_popup_menu_do_popup_modal
- * @popup
- * @pos_func
- * @pos_data
- * @event
- * @user_data
+ * gnome_popup_menu_do_popup_modal:
+ * @popup:
+ * @pos_func:
+ * @pos_data:
+ * @event:
+ * @user_data:
  * 
  * Same as above, but runs the popup menu modally and returns the
  * index of the selected item, or -1 if none.
